@@ -19,41 +19,34 @@
 */
 
 #include "abstractinput.h"
+#include "lskat_debug.h"
 
 // Qt includes
 
 // KDE includes
-#include <kdebug.h>
-
 
 // Constructor for the engine
-AbstractInput::AbstractInput(QObject* parent)
+AbstractInput::AbstractInput(QObject *parent)
     : QObject(parent)
 {
-  mInputAllowed = false;
-  mId           = -1;
+    mInputAllowed = false;
+    mId           = -1;
 }
 
-
 // Set player id number
 void AbstractInput::setId(int id)
 {
-  mId = id;
+    mId = id;
 }
 
-
 // Allow or disallow input with this device
 void AbstractInput::setInputAllowed(bool allowed)
 {
-  mInputAllowed = allowed;
+    mInputAllowed = allowed;
 }
 
-
 // Retrieve whether input is allowed or not.
 bool AbstractInput::inputAllowed()
 {
-  return mInputAllowed;
+    return mInputAllowed;
 }
-
-
-#include "abstractinput.moc"
